@@ -15,8 +15,8 @@ class ContainerLessTC(CubicWebTC):
     def test_adapter_without_container(self):
         u = self.request().execute('CWUser U WHERE U login "admin"').get_entity(0,0)
         adapter = u.cw_adapt_to('Container')
-        self.assertIsNone(adapter.parent)
-        self.assertIsNone(adapter.related_container)
+        self.assertIsNone(adapter)
+
 
 class ContainerEntitiesTC(CubicWebTC):
 
@@ -46,9 +46,7 @@ class ContainerEntitiesTC(CubicWebTC):
         self.commit()
         req = self.request()
         notinside = req.entity_from_eid(notinside.eid)
-        # notinside has a computable parent but no related container
-        self.assertEqual(self.l.eid, notinside.cw_adapt_to('Container').parent.eid)
-        self.assertEqual(None, notinside.cw_adapt_to('Container').related_container)
+        self.assertIsNone(notinside.cw_adapt_to('Container'))
         u = req.entity_from_eid(u.eid)
         self.assertEqual(self.d.eid, u.cw_adapt_to('Container').parent.eid)
         self.assertEqual(self.d.eid, u.cw_adapt_to('Container').related_container.eid)
